Module instance

Module instance 

Instance configuration

Structs

ClientWindowConfig
Configuration for the client window
CommonInstanceConfig
Common full instance config for both client and server
GameModifications
Game modifications
InstanceConfig
Configuration for an instance
LaunchArgs
Arguments for the process when launching
LaunchConfig
Configuration for the launching of the game
WindowResolution
Resolution for a client window
WrapperCommand
A wrapper command

Enums

Args
Different representations for JVM / game arguments
LaunchMemory
Different representations of both memory arguments for the JVM
QuickPlay
Options for the Minecraft QuickPlay feature

Functions

can_install_client_type
Check if a client type can be installed by MCVM
can_install_server_type
Check if a server type can be installed by MCVM
is_valid_instance_id
Checks if an instance ID is valid
merge_instance_configs
Merge an InstanceConfig with a preset