Instance configuration
Structs
- Client
Window Config - Configuration for the client window
- Common
Instance Config - Common full instance config for both client and server
- Game
Modifications - Game modifications
- Instance
Config - Configuration for an instance
- Launch
Args - Arguments for the process when launching
- Launch
Config - Configuration for the launching of the game
- Window
Resolution - Resolution for a client window
- Wrapper
Command - A wrapper command
Enums
- Args
- Different representations for JVM / game arguments
- Launch
Memory - Different representations of both memory arguments for the JVM
- Quick
Play - Options for the Minecraft QuickPlay feature
Functions
- can_
install_ client_ type - Check if a client type can be installed by MCVM
- can_
install_ server_ type - Check if a server type can be installed by MCVM
- is_
valid_ instance_ id - Checks if an instance ID is valid
- merge_
instance_ configs - Merge an InstanceConfig with a preset